@echo off

REM
REM * ============================================================================
REM * Licensed Materials - Property of IBM
REM *  WebSphere sMash
REM *
REM * (C) Copyright IBM Corp. 2008,2010  All Rights Reserved.
REM *
REM * US Government Users Restricted Rights - Use, duplication or disclosure
REM * restricted by GSA ADP Schedule Contract with IBM Corp.
REM * ============================================================================
REM

@setlocal
if "%AB_APP_NAME%" == "" set AB_APP_NAME=appbuilder

if "%AB_LINKTO_MODULE%" == "" set AB_LINKTO_MODULE=zero:zero.appbuilder

set INSTALLED=%ZERO_HOME%\installed
set AB_HOME=%INSTALLED%\%AB_APP_NAME%

set ZEROCMD="%ZERO_HOME%\zero" %ZERO_MAIN_OPTS%

if not exist "%AB_HOME%" goto create_ab
goto run_command

REM -----------------------------------------------------------------
REM Create the AppBuilder application.
REM -----------------------------------------------------------------

:create_ab

echo -------------------------------------------------------
echo Creating the AppBuilder application.
echo This step may take a while.
echo -------------------------------------------------------

REM Create the installed directory.
if not exist "%INSTALLED%" mkdir "%INSTALLED%"

REM Remove the bootstrap application just to be safe.
set BOOTSTRAP_HOME=%INSTALLED%\appbuilder.bootstrap
if exist "%BOOTSTRAP_HOME%" rmdir /S /Q "%BOOTSTRAP_HOME%"

REM Create the bootstrap application.
call %ZEROCMD% create "%BOOTSTRAP_HOME%"
if not %ERRORLEVEL% == 0 goto create_bootstrap_failed
cd /d "%BOOTSTRAP_HOME%"

REM Adjust the bootstrap application's dependencies to pull zero:zero.cli.tasks:[1.0.0.0,).
REM This is necessary to allow switching from a 1.x to a 2.x modulegroup.
type "%SCRIPT_HOME%\config\appbuilder-bootstrap-ivy.xml" > "%BOOTSTRAP_HOME%\config\ivy.xml"
call %ZEROCMD% update
if not %ERRORLEVEL% == 0 goto update_bootstrap_failed

REM Switch to the experimental modulegroup.
call %ZEROCMD% switch experimental 1>nul 2>nul
if not %ERRORLEVEL% == 0 goto create_experimental
goto do_create_ab

REM Create the experimental modulegroup and switch to it.
:create_experimental
call %ZEROCMD% modulegroup create experimental
if not %ERRORLEVEL% == 0 goto create_experimental_failed
call %ZEROCMD% switch experimental
if not %ERRORLEVEL% == 0 goto switch_experimental_failed
goto do_create_ab

REM Create the AppBuilder.
:do_create_ab
echo  Doing zero create of "%AB_HOME%"  with linkto  "%AB_LINKTO_MODULE%"
call %ZEROCMD% create "%AB_HOME%" linkto "%AB_LINKTO_MODULE%"
if not %ERRORLEVEL% == 0 goto create_ab_failed
cd /d "%ZERO_HOME%"
rmdir /S /Q "%BOOTSTRAP_HOME%"
goto run_command

REM -----------------------------------------------------------------
REM Run the specified command.
REM -----------------------------------------------------------------

:run_command
set ZRP=%AB_HOME%\.zero\private\resolved.properties
set SCRIPT_HOME=
for /F "usebackq eol=; tokens=1,2* delims==" %%i in ("%ZRP%") do if %%i == zero.appbuilder.core ( set SCRIPT_HOME=%%j\.)
set SCRIPT_HOME=%SCRIPT_HOME:\:=:%
set SCRIPT_HOME=%SCRIPT_HOME:\\=\%
if exist "%SCRIPT_HOME%\appbuilder.bat" goto call_script

echo Failed to find zero.appbuilder.core\appbuilder.bat.
echo Running command against zero.cli.tasks\zero.bat.
cd /d "%AB_HOME%"
call %ZEROCMD% %*
if not %ERRORLEVEL% == 0 goto zct_handling_failed
goto end

:call_script
call "%SCRIPT_HOME%\appbuilder" %*
goto end

REM -----------------------------------------------------------------
REM Error handling
REM -----------------------------------------------------------------

:create_bootstrap_failed
echo ERROR: Failed to create bootstrap application at %BOOTSTRAP_HOME%
if exist "%BOOTSTRAP_HOME%" rmdir /S /Q "%BOOTSTRAP_HOME%"
goto end

:update_bootstrap_failed
echo ERROR: Failed to update the bootstrap application at %BOOTSTRAP_HOME%
if exist "%BOOTSTRAP_HOME%" rmdir /S /Q "%BOOTSTRAP_HOME%"
goto end

:create_experimental_failed
echo ERROR: Failed to create the experimental modulegroup
if exist "%BOOTSTRAP_HOME%" rmdir /S /Q "%BOOTSTRAP_HOME%"
goto end

:switch_experimental_failed
echo ERROR: Failed to switch to the experimental modulegroup
if exist "%BOOTSTRAP_HOME%" rmdir /S /Q "%BOOTSTRAP_HOME%"
goto end

:create_ab_failed
echo ERROR: Failed to create the AppBuilder application at %AB_HOME%
if exist "%BOOTSTRAP_HOME%" rmdir /S /Q "%BOOTSTRAP_HOME%"
if exist "%AB_HOME%" rmdir /S /Q "%AB_HOME%"
goto end

:zct_handling_failed
echo.
echo The task you tried to invoke failed.  Please execute 'appbuilder resolve' 
echo or 'appbuilder update' to fix your environment.
goto end

REM -----------------------------------------------------------------
REM Done
REM -----------------------------------------------------------------

:end
exit /b %EXIT_CODE%
@endlocal
